.. note:: This module is a work in progress and will be gradually updated.

pyrolite\.mineral\.template
-------------------------------
  .. automodule:: pyrolite.mineral.template
      :members:
      :undoc-members:


pyrolite\.mineral\.normative
-------------------------------
  .. automodule:: pyrolite.mineral.normative
      :members:
      :undoc-members:


pyrolite\.mineral\.transform
-------------------------------
  .. automodule:: pyrolite.mineral.transform
      :members:
      :undoc-members:


pyrolite\.mineral\.sites
-------------------------------
  .. automodule:: pyrolite.mineral.sites
      :members:
      :undoc-members:


pyrolite\.mineral\.lattice
-------------------------------
  .. automodule:: pyrolite.mineral.lattice
      :members:
      :undoc-members:


pyrolite\.mineral\.mindb
-------------------------------
  .. automodule:: pyrolite.mineral.mindb
      :members:
      :undoc-members:
